16.41. cdist-type__docker_config(7) — cdist 6.5.4 documentation

# 16.41. cdist-type__docker_config(7)

## 16.41.1. NAME

cdist-type__docker_config - Manage Docker configs

## 16.41.2. DESCRIPTION

This type manages Docker configs.

## 16.41.3. OPTIONAL PARAMETERS

source
  Path to the source file. If it is '-' (dash), read standard input.
state

  'present' or 'absent', defaults to 'present' where:

  present
    if the config does not exist, it is created
  absent
    the config is removed

## 16.41.4. CAVEATS

Since Docker configs cannot be updated once created, this type tries removing and recreating the config if it changes. If the config is used by a service at the time of removing, then this type will fail.

## 16.41.5. EXAMPLES

    # Creates "foo" config from "bar" source file
    __docker_config foo --source bar

## 16.41.6. AUTHORS

Ľubomír Kučera <lubomir.kucera.jr at gmail.com>

## 16.41.7. COPYING

Copyright (C) 2018 Ľubomír Kučera. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.